use maud::{html, PreEscaped, DOCTYPE};

/// JavaScript event listener for the back button on the top navigation bar of
/// the UI.
///
/// When the button is clicked, prevent the default behaviour and invoke
/// the history API to load the previous URL (page) in the history list.
fn js_back_button_script() -> PreEscaped<String> {
    html! {
        (PreEscaped("
            <script>
                document.addEventListener('DOMContentLoaded', function () {
                    document.getElementById('backButton').onclick = function(e) {
                        e.preventDefault();
                        history.back();
                    }
                });
            </script>
        "))
    }
}

/// Base template builder.
///
/// Takes an HTML body as input and splices it into the base template.
pub fn build_template(body: PreEscaped<String>, theme: String) -> PreEscaped<String> {
    html! {
        (DOCTYPE)
        html lang="en" data-theme=(theme);
        head {
            meta charset="utf-8";
            meta name="description" content="PeachCloud web interface";
            meta name="author" content="glyph and notplants";
            meta name="viewport" content="width=devide-width, initial-scale=1.0";
            link rel="stylesheet" href="/css/peachcloud.css";
            link rel="stylesheet" href="/css/_variables.css";
            (js_back_button_script())
            title { "PeachCloud" }
        }
        body {
            (body)
        }
    }
}
